# -*- coding: utf-8 -*-
"""
In this folder, there are tests belonging to the application.

@author: Sergei Klykov
@licence: MIT
"""
__all__ = ['test_calculations', 'test_polynomials_initialization']
